@@ -23,7 +23,10 @@
 
 #------------------------------------------------------------------------------------------
 """
-This script is responsible for efficient uploading of multi file data
+Reserves a ''study'' with the given name. 
+Study with this name could be used afterwards as explicitly, by [[cloudflu-upload-start]],
+[[cloudflu-upload-resume]] and [[cloudflu-download]] utilities, as implicitly, 
+by interaction between [[cloudflu-solver-start]] and [[cloudflu-solver-process]].
 """
 
 
@@ -87,8 +90,6 @@ def main() :
     #----------------------- Definition of the command line arguments ------------------------
     study_book_options.add( an_option_parser )
 
-    common.communication_options.add( an_option_parser )
-
     amazon.security_options.add( an_option_parser )
     
     common.options.add( an_option_parser )
@@ -99,8 +100,6 @@ def main() :
 
     common.options.extract( an_option_parser )
     
-    common.communication_options.extract( an_option_parser )
-
     AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY = amazon.security_options.extract( an_option_parser )
     
     a_study_name = study_book_options.extract( an_option_parser )
