@@ -103,7 +103,7 @@ def dump_resume( the_identation_level, the_option_group, the_output ) :
         a_default = an_option.default
         a_dest = an_option.dest
 
-        if a_dest in [ 'cluster_location', 'image_id', 'data_location', 'enable_debug', 'production', 'instance_type' ] :
+        if a_dest in [ 'cluster_location', 'image_id', 'data_location', 'enable_debug', 'production', 'instance_type', 'wait_run' ] :
             a_default = 'a_helper.%s()' % a_dest
             pass
 
@@ -208,7 +208,20 @@ def pickup() :
 #--------------------------------------------------------------------------------------
 REGION2PARAMS = { 'us-east-1' : [ '', { 'openfoam171_0-1ubuntu2' : 'ami-ecf50385', 
                                         'openfoam171_0-1' : 'ami-62fa0c0b', 
-                                        'openfoam-dev-1.5' : 'ami-98f701f1' } ] }
+                                        'openfoam-dev-1.5' : 'ami-98f701f1',
+                                        'openfoam-1.6-ext' : 'ami-b2fd0cdb' } ],
+                  'eu-west-1' : [ 'EU', { 'openfoam171_0-1ubuntu2' : 'ami-519ca925',
+                                          'openfoam171_0-1' : 'ami-8d9da8f9',
+                                          'openfoam-dev-1.5' : 'ami-4d9ca939',
+                                          'openfoam-1.6-ext' : 'ami-f998ad8d' } ],
+                  'ap-southeast-1' : [ 'ap-southeast-1', { 'openfoam171_0-1ubuntu2' : 'ami-d2423c80',
+                                                           'openfoam171_0-1' : 'ami-28423c7a',
+                                                           'openfoam-dev-1.5' : 'ami-2c423c7e',
+                                                           'openfoam-1.6-ext' : 'ami-3a433d68' } ],
+                  'us-west-1' : [ 'us-west-1', { 'openfoam171_0-1ubuntu2' : 'ami-bb7e2efe',
+                                                 'openfoam171_0-1' : 'ami-8d7e2ec8',
+                                                 'openfoam-dev-1.5' : 'ami-a97e2eec',
+                                                 'openfoam-1.6-ext' : 'ami-5f60301a' } ] }
 
 
 #--------------------------------------------------------------------------------------
@@ -246,6 +259,9 @@ class Helper :
     def instance_type( self ) :
         return self._instance_type
     
+    def wait_run( self ) :
+        return self._enable_debug
+    
     pass
 
 
